<?php
function shrinktheweb_admin_log($form, $form_state) {
  $form = array();

  if(!isset($form_state['storage']['confirm'])) {
    $log_records = array();

    // format the tableselect header
    $header = array(
      'url' => array('data' => t('URL'), 'field' => 'sl.url'),
      'result' => array('data' => t('Result'), 'field' => 'sl.result'),
      'ts' => array('data' => t('Timestamp'), 'field' => 'sl.ts'),
      'cnt' => array('data' => t('# of requests'), 'field' => 'sl.cnt')
    );

    // get the log records
    $result = db_select('shrinktheweb_log', 'sl')
      ->fields('sl')
      ->extend('PagerDefault')
      ->limit(25)
      ->extend('TableSort')
      ->orderByHeader($header)
      ->addTag('shrinktheweb_log_records')
      ->execute();

    foreach ($result as $record) {
      $log_records[$record->id] = array(
        'url' => $record->url,
        'result' => $record->result,
        'ts' => format_date($record->ts),
        'cnt' => $record->cnt
      );
    }

    //check if there are any records in the log
    if (empty($log_records)) {
      return array(
        'no_records' => array('#markup' => t('The log is empty.'))
      );
    }

    $form['log_records'] = array(
      '#type' => 'tableselect',
      '#header' => $header,
      '#options' => $log_records,
      '#tree' => FALSE
    );

    $form['pager'] = array(
      '#theme' => 'pager',
    );

    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Delete selected records')
    );

    return $form;
  }
  else{
    return confirm_form(
      $form,
      t('Do you want to delete the record(s)?'),
      'admin/config/media/shrinktheweb/log'
    );
  }
}

function shrinktheweb_admin_log_validate($form, $form_state) {
  if(!isset($form_state['storage']['confirm'])) {
    $log_recs = array_filter($form_state['values']['log_records']);
    if (empty($log_recs)) {
      form_set_error('log_records', t('Please select a log record!'));
    }
  }
}

function shrinktheweb_admin_log_submit($form, &$form_state) {
  if(!isset($form_state['storage']['confirm'])) {
    $form_state['storage']['confirm'] = TRUE;
    $form_state['storage']['log_records'] = array_filter($form_state['values']['log_records']);
    $form_state['rebuild'] = TRUE;
  }
  else {
    if (!empty($form_state['storage']['log_records'])) {
      $num_deleted = db_delete('shrinktheweb_log')
        ->condition('id', $form_state['storage']['log_records'], 'IN')
        ->execute();
      drupal_set_message(t('Deletion successful.'));
    }
  }
}

function shrinktheweb_admin_settings() {
  $form = array();

  $form['shrinktheweb_keys'] = array(
    '#type' => 'fieldset',
    '#title' => t('ShrinkTheWeb API keys'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  );

  $form['shrinktheweb_keys']['shrinktheweb_access_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Access key'),
    '#default_value' => variable_get('shrinktheweb_access_key', ''),
    '#required' => TRUE,
  );
  $form['shrinktheweb_keys']['shrinktheweb_secret_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Secret key'),
    '#default_value' => variable_get('shrinktheweb_secret_key', ''),
    '#required' => TRUE,
  );
  $form['shrinktheweb_thumbs_folder'] = array(
    '#type' => 'textfield',
    '#title' => t('Thumbnails folder'),
    '#default_value' => variable_get('shrinktheweb_thumbs_folder', 'shrinktheweb_thumbnails'),
    '#required' => TRUE,
    '#description' => t('This is a subfolder of the "File system path" folder.'),
  );
  $form['shrinktheweb_cache_days'] = array(
    '#type' => 'textfield',
    '#title' => t('Days in cache'),
    '#default_value' => variable_get('shrinktheweb_cache_days', 3),
    '#description' => t('Leave empty for unlimited days in cache.'),
    '#size' => 10,
  );
  $form['shrinktheweb_parameters'] = array(
    '#type' => 'textarea',
    '#title' => t('Request parameters'),
    '#default_value' => variable_get('shrinktheweb_parameters', ''),
    '#description' => t('Submit each parameter/value group on new line. For example: "stwinside=1". Check the ShrinkTheWeb API documentation for more information.'),
  );

  return system_settings_form($form);
}

function shrinktheweb_admin_settings_validate($form, &$form_state) {
  $cache_days = $form_state['values']['shrinktheweb_cache_days'];
  if (!empty($cache_days)) {
    if (!is_numeric($cache_days)) {
      form_set_error('shrinktheweb_cache_days', t('You must enter an integer for the days in cache.'));
    }
    else if ($cache_days < 0) {
      form_set_error('shrinktheweb_cache_days', t('Maximum number of days in cache must be positive.'));
    }
  }
}
